.. pvfactors_documentation

Welcome to the pvfactors documentation!
=======================================

.. figure:: _static/logo.png
   :align: center
   :width: 60%

| ``pvfactors`` is an open-source Python library that makes it easy to calculate incident irradiance on various surfaces of a PV array, including back side PV surfaces. ``pvfactors`` was originally ported from the SunPower developed ``vf_model`` package which was first presented at the IEEE PV Specialist Conference 44 ([#vf_paper]_, link_ to paper).
| You can find explanations on how to install the package in the :ref:`installation` section, and learn how to use it using both the :ref:`tutorials` and :ref:`developer_api` sections, but preferably after reading the :ref:`concepts` section.

.. _link: https://pdfs.semanticscholar.org/ebb2/35e3c3796b158e1a3c45b40954e60d876ea9.pdf

Citing pvfactors
----------------

We appreciate your use of ``pvfactors``.
If you use ``pvfactors`` in a published work, we kindly ask that you cite:

   Anoma, M., Jacob, D., Bourne, B.C., Scholl, J.A., Riley, D.M. and Hansen, C.W., 2017. View Factor Model and Validation for Bifacial PV and Diffuse Shade on Single-Axis Trackers. In 44th IEEE Photovoltaic Specialist Conference.

Contents
--------

.. toctree::
   :maxdepth: 2

   installation/index.rst
   concepts/index.rst
   tutorials/index.rst
   theory/index.rst
   developer/index.rst
   whatsnew.rst


Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`


.. rubric:: Footnotes

.. [#vf_paper] Anoma, M., Jacob, D., Bourne, B.C., Scholl, J.A., Riley, D.M. and Hansen, C.W., 2017. View Factor Model and Validation for Bifacial PV and Diffuse Shade on Single-Axis Trackers. In 44th IEEE Photovoltaic Specialist Conference.
